Documentation
¶
Index ¶
- Constants
- Variables
- func CheckSQLiteSchemaVersion(version string) error
- func HashAttemptToken(token string) string
- func NewAttemptToken() (string, error)
- func RejectSharedWritableParent(path string) error
- func RejectSymlinkPath(path string) error
- func RestrictLocalFile(path string) error
- func ValidateAttemptToken(token string) error
- func ValidateKey(key string) error
- func ValidateSQLitePath(path string) error
- type ListOptions
- type PruneOptions
- type PruneResult
- type Record
- type SQLiteStore
- func (s *SQLiteStore) AdminForget(key string, force bool) (bool, error)
- func (s *SQLiteStore) Close() error
- func (s *SQLiteStore) Commit(key, attempt string, state State, exitCode int, stdout, stderr []byte, ...) (Record, error)
- func (s *SQLiteStore) Forget(key string, force bool, attempt string) (bool, error)
- func (s *SQLiteStore) Get(key string) (Record, error)
- func (s *SQLiteStore) List(opts ListOptions) ([]Record, error)
- func (s *SQLiteStore) Prune(opts PruneOptions) (PruneResult, error)
- func (s *SQLiteStore) Reserve(key string, command []string) (Record, bool, error)
- type State
- type Store
Constants ¶
const MaxKeyLen = 256
Variables ¶
Functions ¶
func CheckSQLiteSchemaVersion ¶ added in v0.6.0
CheckSQLiteSchemaVersion rejects stores that need a different once binary.
func HashAttemptToken ¶
func NewAttemptToken ¶
func RejectSharedWritableParent ¶ added in v0.5.0
func RejectSymlinkPath ¶
func RestrictLocalFile ¶
func ValidateAttemptToken ¶
func ValidateKey ¶
func ValidateSQLitePath ¶ added in v0.2.2
ValidateSQLitePath rejects SQLite DSN forms. once stores must be local filesystem paths so SQLite options cannot bypass local file checks.
Types ¶
type ListOptions ¶ added in v0.2.0
type PruneOptions ¶ added in v0.2.1
type PruneResult ¶ added in v0.2.1
type SQLiteStore ¶
type SQLiteStore struct {
// contains filtered or unexported fields
}
func OpenSQLite ¶
func OpenSQLite(path string) (*SQLiteStore, error)
func (*SQLiteStore) AdminForget ¶
func (s *SQLiteStore) AdminForget(key string, force bool) (bool, error)
func (*SQLiteStore) Close ¶
func (s *SQLiteStore) Close() error
func (*SQLiteStore) List ¶ added in v0.2.0
func (s *SQLiteStore) List(opts ListOptions) ([]Record, error)
func (*SQLiteStore) Prune ¶ added in v0.2.1
func (s *SQLiteStore) Prune(opts PruneOptions) (PruneResult, error)
type Store ¶
type Store interface {
Close() error
Reserve(key string, command []string) (Record, bool, error)
Commit(key, attempt string, state State, exitCode int, stdout, stderr []byte, runErr string) (Record, error)
Get(key string) (Record, error)
Forget(key string, force bool, attempt string) (bool, error)
}
Click to show internal directories.
Click to hide internal directories.